Graphical User Interface — TARDIS v0.9.dev692

# Graphical User Interface

TARDIS uses the PyQt4 framework for its cross-platform interface.

The GUI runs through the IPython Interpreter which should be started with the command `ipython-2.7 --pylab=qt`, so that it has acess to pylab.

Creating an instance of the `ModelViewer`-class requires that PyQt4 has already been initialized in IPython. The above command to start IPython accomplishes this.

## GUI Layout and Features